| Title: | EFSA OpenFoodTox Data Made Accessible as an R Package |
|---|---|
| Description: | Provides convenient access to data extracted from some of the spreadsheet files made available by the chemical hazards database of the European Food Safety Authority (EFSA), accessible via <https://www.efsa.europa.eu/en/data-report/chemical-hazards-database-openfoodtox>. |
| Authors: | Johannes Ranke [aut, cre] (ORCID: <https://orcid.org/0000-0003-4371-6538>), Elisabeth Lutz [ctb], Romualdus Kasteel [rev], Marcel Mathis [rev], European Food Safety Authority [dtc], Agroscope [cph] |
| Maintainer: | Johannes Ranke <[email protected]> |
| License: | GPL |
| Version: | 0.1.3 |
| Built: | 2026-05-19 09:07:48 UTC |
| Source: | https://github.com/agroscope-ch/openfoodtox |
This data object was created to facilitate the access to the list of so-called 'reference points' published as part of the OpenFoodTox datasets (Carnesecchi et al. 2023). These reference points are linked to substance characterisations and the outputs of the European Food Safety Authority (EFSA) in which the data were published. Also, a table of 'reference values' is included, which is also linked to substance characterisations and EFSA outputs. Other data tables published as part of OpenFoodTox are not included in this R package.
oftoft
list A dm::dm object
See vignette("OpenFoodTox") for a description of the contents of the individual
tables.
The R code used to create this data object is installed with this package in the 'dataset_generation' directory.
Carnesecchi E, Mostrag A, Ciacci A, Roncaglioni A, Tarkhov A, Gibin D, Sartori L, Benfenati E, Yang C, Dorne JLCM (2023). OpenFoodTox: EFSA's chemical hazards database (Version 5). Zenodo. doi:10.5281/zenodo.8120114
Dorne JLCM, Richardson J, Livaniou A, Carnesecchi E, Ceriani L, Baldin R, Kovarich S, Pavan M, Saouter E, Biganzoli F, Pasinato L, Zare Jeddi M, Robinson TP, Kass GEN, Liem AKD, Toropov AA, Toropova AP, Yang C, Tarkhov A, Georgiadis N, Di Nicola MR, Mostrag A, Verhagen H, Roncaglioni A, Benfenati E, Bassan A. EFSA's OpenFoodTox: An open source toxicological database on chemicals in food and feed and its future developments. Environ Int. 2021 Jan;146:106293. doi:10.1016/j.envint.2020.106293
species_group
library(dm, warn.conflicts = FALSE) library(dplyr, warn.conflicts = FALSE) # Show the relational structure of the data tables (only works in online HTML help) dm_draw(oft, view_type = "all") # List species used in aquatic tests oft$reference_points |> dplyr::filter(Study == "Ecotox (water compartment)") |> select(Species) |> unique() |> arrange(Species) |> print(n = Inf) # Collect endpoints on green algae green_algae_endpoints <- oft$reference_points |> dplyr::filter(Species %in% oft_aq_green_algae) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect) print(green_algae_endpoints) # Show aquatic endpoints for spinosad oft$reference_points |> dplyr::filter(Study == "Ecotox (water compartment)") |> dplyr::filter(grepl("^Spinos", Substance)) |> arrange(Species) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect) # Check substance characterisation of spinosad (no useful information available) oft$substance_characterisation |> dplyr::filter(grepl("^Spinos", Substance)) # List species used in terrestrial tests oft$reference_points |> dplyr::filter(Study == "Ecotox (soil compartment)") |> select(Species) |> unique() |> arrange(Species) |> print(n = Inf) # Show terrestrial endpoints for spinosad oft$reference_points |> dplyr::filter(Study == "Ecotox (soil compartment)") |> dplyr::filter(grepl("^Spinos", Substance)) |> arrange(Species) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect) # Show terrestrial endpoints for terbuthylazine oft$reference_points |> dplyr::filter(Study == "Ecotox (soil compartment)") |> dplyr::filter(grepl("^Terbuthyl", Substance)) |> arrange(Species) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect) # Show terrestrial endpoints for florasulam (an example where terrestrial plant data are available) oft$reference_points |> dplyr::filter(Study == "Ecotox (soil compartment)") |> dplyr::filter(grepl("^Floras", Substance)) |> arrange(Species) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect)library(dm, warn.conflicts = FALSE) library(dplyr, warn.conflicts = FALSE) # Show the relational structure of the data tables (only works in online HTML help) dm_draw(oft, view_type = "all") # List species used in aquatic tests oft$reference_points |> dplyr::filter(Study == "Ecotox (water compartment)") |> select(Species) |> unique() |> arrange(Species) |> print(n = Inf) # Collect endpoints on green algae green_algae_endpoints <- oft$reference_points |> dplyr::filter(Species %in% oft_aq_green_algae) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect) print(green_algae_endpoints) # Show aquatic endpoints for spinosad oft$reference_points |> dplyr::filter(Study == "Ecotox (water compartment)") |> dplyr::filter(grepl("^Spinos", Substance)) |> arrange(Species) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect) # Check substance characterisation of spinosad (no useful information available) oft$substance_characterisation |> dplyr::filter(grepl("^Spinos", Substance)) # List species used in terrestrial tests oft$reference_points |> dplyr::filter(Study == "Ecotox (soil compartment)") |> select(Species) |> unique() |> arrange(Species) |> print(n = Inf) # Show terrestrial endpoints for spinosad oft$reference_points |> dplyr::filter(Study == "Ecotox (soil compartment)") |> dplyr::filter(grepl("^Spinos", Substance)) |> arrange(Species) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect) # Show terrestrial endpoints for terbuthylazine oft$reference_points |> dplyr::filter(Study == "Ecotox (soil compartment)") |> dplyr::filter(grepl("^Terbuthyl", Substance)) |> arrange(Species) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect) # Show terrestrial endpoints for florasulam (an example where terrestrial plant data are available) oft$reference_points |> dplyr::filter(Study == "Ecotox (soil compartment)") |> dplyr::filter(grepl("^Floras", Substance)) |> arrange(Species) |> select(Substance, Species, DurationDays, Endpoint, qualifier, value, unit, Effect)
Aquatic Cyanobacteria
oft_aq_cyanobacteriaoft_aq_cyanobacteria
An object of class character of length 4.
Other oft_species_group:
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_aq_cyanobacteria)print(oft_aq_cyanobacteria)
Aquatic diatoms
oft_aq_diatom_algaeoft_aq_diatom_algae
An object of class character of length 3.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_aq_diatom_algae)print(oft_aq_diatom_algae)
Fish
oft_aq_fishoft_aq_fish
An object of class character of length 23.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_aq_fish)print(oft_aq_fish)
Aquatic green algae
oft_aq_green_algaeoft_aq_green_algae
An object of class character of length 8.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_aq_green_algae)print(oft_aq_green_algae)
Aquatic invertebrates
oft_aq_invertebratesoft_aq_invertebrates
An object of class character of length 22.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_aq_invertebrates)print(oft_aq_invertebrates)
Aquatic macrophytes
oft_aq_macrophytesoft_aq_macrophytes
An object of class character of length 10.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_aq_macrophytes)print(oft_aq_macrophytes)
Aquatic primary producers
oft_aq_primary_producersoft_aq_primary_producers
An object of class character of length 25.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_aq_primary_producers)print(oft_aq_primary_producers)
Beneficial Arthropods
oft_arthropodsoft_arthropods
An object of class character of length 12.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_arthropods)print(oft_arthropods)
Bees
oft_beesoft_bees
An object of class character of length 1.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_bees)print(oft_bees)
Birds
oft_birdsoft_birds
An object of class character of length 17.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_birds)print(oft_birds)
Earthworms
oft_earthwormsoft_earthworms
An object of class character of length 5.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_mammals,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_earthworms)print(oft_earthworms)
Convenience function to group species into fish, aquatic invertebrates, aquatic primary producers, birds, mammals, bees, earthworms, arthropods and plants. The entries 'Unspecified' and 'not reported' are translated to NA.
oft_group_species(species)oft_group_species(species)
species |
The species name, i.e. the Species column in the referenec point table |
A species group name
library(dplyr) oft$reference_points |> dplyr::filter(Substance == "Thiacloprid") |> mutate(Species_group = oft_group_species(Species)) |> select(Substance, Species, Species_group, Endpoint, qualifier, value, unit, Effect)library(dplyr) oft$reference_points |> dplyr::filter(Substance == "Thiacloprid") |> mutate(Species_group = oft_group_species(Species)) |> select(Substance, Species, Species_group, Endpoint, qualifier, value, unit, Effect)
Mammals
oft_mammalsoft_mammals
An object of class character of length 17.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_other,
oft_plants,
oft_soil_macroorganisms
print(oft_mammals)print(oft_mammals)
Other
oft_otheroft_other
An object of class character of length 2.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_plants,
oft_soil_macroorganisms
print(oft_other)print(oft_other)
Plants
oft_plantsoft_plants
An object of class character of length 27.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_soil_macroorganisms
print(oft_plants)print(oft_plants)
Soil macroorganisms
oft_soil_macroorganismsoft_soil_macroorganisms
An object of class character of length 7.
Other oft_species_group:
oft_aq_cyanobacteria,
oft_aq_diatom_algae,
oft_aq_fish,
oft_aq_green_algae,
oft_aq_invertebrates,
oft_aq_macrophytes,
oft_aq_primary_producers,
oft_arthropods,
oft_bees,
oft_birds,
oft_earthworms,
oft_mammals,
oft_other,
oft_plants
print(oft_soil_macroorganisms)print(oft_soil_macroorganisms)